@@ -236,16 +236,18 @@ class DSMRReader():
       #   usage_gas_total = str(telegram[obis_ref.HOURLY_GAS_METER_READING].value * 1000)
       # )
 
+      # TODO: add uom: telegram.CURRENT_ELECTRICITY_USAGE.unit
+
       data = dict(
         unix_timestamp = int(time.time()),
-        current_electricity_usage = str(telegram[obis_ref.CURRENT_ELECTRICITY_USAGE] * 1000),
-        current_electricity_delivery = str(telegram[obis_ref.CURRENT_ELECTRICITY_DELIVERY] * 1000),
-        electricity_active_tariff = str(telegram[obis_ref.ELECTRICITY_ACTIVE_TARIFF]),
-        usage_total_low = str(telegram[obis_ref.ELECTRICITY_USED_TARIFF_1] * 1000),
-        usage_total_high = str(telegram[obis_ref.ELECTRICITY_USED_TARIFF_2] * 1000),
-        redelivery_total_low = str(telegram[obis_ref.ELECTRICITY_DELIVERED_TARIFF_1] * 1000),
-        redelivery_total_high = str(telegram[obis_ref.ELECTRICITY_DELIVERED_TARIFF_2] * 1000),
-        usage_gas_total = str(telegram[obis_ref.HOURLY_GAS_METER_READING] * 1000)
+        current_electricity_usage = str(telegram.CURRENT_ELECTRICITY_USAGE.value * 1000),
+        current_electricity_delivery = str(telegram.CURRENT_ELECTRICITY_DELIVERY.value * 1000),
+        electricity_active_tariff = str(telegram.ELECTRICITY_ACTIVE_TARIFF.value),
+        usage_total_low = str(telegram.ELECTRICITY_USED_TARIFF_1.value * 1000),
+        usage_total_high = str(telegram.ELECTRICITY_USED_TARIFF_2.value * 1000),
+        redelivery_total_low = str(telegram.ELECTRICITY_DELIVERED_TARIFF_1.value * 1000),
+        redelivery_total_high = str(telegram.ELECTRICITY_DELIVERED_TARIFF_2.value * 1000),
+        usage_gas_total = str(telegram.HOURLY_GAS_METER_READING].value.value * 1000)
       )
 
       if self.debug:
@@ -272,8 +274,7 @@ class DSMRReader():
 
           t = dict()
 
-          # for telegram in self.serial_reader.read_as_object():
-          for telegram in self.serial_reader.read():
+          for telegram in self.serial_reader.read_as_object():
             # now, translate telegram to dict
             obj = self.extract_data_from_telegram(telegram)
 
